@@ -1,4 +1,6 @@
-from cookgame import cookgame
+from cookgame.game import Kitchen
+from .game import Kitchen
+
 print('*' * 30)
 print('power by coding-ai.cn')
 print('*' * 30)
\ No newline at end of file
